==> jswat_1.7.orig.tar.gz: jswat-1.7/classes/com/bluemarsh/jswat/action/CatchAction.java <==
/*********************************************************************
 *
 *      Copyright (C) 2002 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      JSwat Actions
 * FILE:        CatchAction.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      03/31/02        Initial version
 *
 * DESCRIPTION:
 *      Defines the class responsible for creating catches.
 *
 * $Id: CatchAction.java 629 2002-10-26 23:03:26Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.action;

import com.bluemarsh.jswat.Session;
import com.bluemarsh.jswat.breakpoint.BreakpointManager;
import com.bluemarsh.jswat.breakpoint.ResolveException;
import java.awt.Frame;
import java.awt.Label;
import java.awt.event.ActionEvent;
import javax.swing.JOptionPane;
import javax.swing.JTextField;

/**
 * Class CatchAction allows the user to define new exception catches.
 *
 * @author  Nathan Fiedler
 */
public class CatchAction extends JSwatAction {

    /**
     * Creates a new CatchAction object with the default action
     * command string of "catch".
     */
    public CatchAction() {
        super("catch");
    } // CatchAction

    /**
     * Performs the create exception catch action.
     *
     * @param  event  action event
     */
    public void actionPerformed(ActionEvent event) {
        Frame win = getFrame(event);
        Session session = getSession(event);

        Object messages[] = {
            Bundle.getString("Catch.exceptionField"),
            new JTextField(25),
        };

        String className = null;
        boolean responseOkay = false;
        while (!responseOkay) {
            // Show dialog asking user for catch information.
            int response = JOptionPane.showOptionDialog(
                win, messages, Bundle.getString("Catch.title"),
                JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE,
                null, null, null);
            if (response != JOptionPane.OK_OPTION) {
                return;
            }

            // Now assume the response is okay unless we find otherwise.
            responseOkay = true;
            className = ((JTextField) messages[1]).getText();
            if (className.length() == 0) {
                JOptionPane.showMessageDialog(
                    win,
                    Bundle.getString("Catch.missingClassName"),
                    Bundle.getString("Catch.errorTitle"),
                    JOptionPane.ERROR_MESSAGE);
                responseOkay = false;
            }
        }

        // Create the catch.
        BreakpointManager brkman = (BreakpointManager)
            session.getManager(BreakpointManager.class);
        try {
            brkman.createExceptionCatch(className);
            session.getStatusLog().writeln(Bundle.getString("Catch.added"));
        } catch (ClassNotFoundException cnfe) {
            JOptionPane.showMessageDialog(
                win,
                Bundle.getString("Catch.invalidClassMsg"),
                Bundle.getString("Catch.errorTitle"),
                JOptionPane.ERROR_MESSAGE);
        } catch (ResolveException re) {
            JOptionPane.showMessageDialog(
                win, re.errorMessage(),
                Bundle.getString("Catch.errorTitle"),
                JOptionPane.ERROR_MESSAGE);
        }
    } // actionPerformed
} // CatchAction

==> jswat2_2.33.orig.tar.gz: jswat2-2.33.orig/classes/com/bluemarsh/jswat/action/CatchAction.java <==
/*********************************************************************
 *
 *      Copyright (C) 2002-2003 Nathan Fiedler
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * PROJECT:     JSwat
 * MODULE:      JSwat Actions
 * FILE:        CatchAction.java
 *
 * AUTHOR:      Nathan Fiedler
 *
 * REVISION HISTORY:
 *      Name    Date            Description
 *      ----    ----            -----------
 *      nf      03/31/02        Initial version
 *
 * $Id: CatchAction.java 1048 2003-11-16 07:27:16Z nfiedler $
 *
 ********************************************************************/

package com.bluemarsh.jswat.action;

import com.bluemarsh.jswat.Session;
import com.bluemarsh.jswat.breakpoint.Breakpoint;
import com.bluemarsh.jswat.breakpoint.BreakpointManager;
import com.bluemarsh.jswat.breakpoint.ExceptionBreakpoint;
import com.bluemarsh.jswat.breakpoint.ResolveException;
import com.bluemarsh.jswat.ui.UIAdapter;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import javax.swing.JOptionPane;
import javax.swing.JTextField;

/**
 * Class CatchAction allows the user to define new exception catches.
 *
 * @author  Nathan Fiedler
 */
public class CatchAction extends JSwatAction {

    /**
     * Creates a new CatchAction object with the default action
     * command string of "catch".
     */
    public CatchAction() {
        super("catch");
    } // CatchAction

    /**
     * Performs the create exception catch action.
     *
     * @param  event  action event
     */
    public void actionPerformed(ActionEvent event) {
        Frame win = getFrame(event);
        Session session = getSession(event);

        Object[] messages = {
            Bundle.getString("Catch.exceptionField"),
            new JTextField(25),
        };

        String className = null;
        boolean responseOkay = false;
        while (!responseOkay) {
            // Show dialog asking user for catch information.
            int response = JOptionPane.showOptionDialog(
                win, messages, Bundle.getString("Catch.title"),
                JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE,
                null, null, null);
            if (response != JOptionPane.OK_OPTION) {
                return;
            }

            // Now assume the response is okay unless we find otherwise.
            responseOkay = true;
            className = ((JTextField) messages[1]).getText();
            if (className.length() == 0) {
                session.getUIAdapter().showMessage(
                    UIAdapter.MESSAGE_ERROR,
                    Bundle.getString("Catch.missingClassName"));
                responseOkay = false;
            }
        }

        // Create the catch.
        BreakpointManager brkman = (BreakpointManager)
            session.getManager(BreakpointManager.class);
        try {
            Breakpoint bp = new ExceptionBreakpoint(className, true, true);
            brkman.addNewBreakpoint(bp);
            session.getUIAdapter().showMessage(
                UIAdapter.MESSAGE_NOTICE,
                Bundle.getString("Catch.added"));
        } catch (ClassNotFoundException cnfe) {
            session.getUIAdapter().showMessage(
                UIAdapter.MESSAGE_ERROR,
                Bundle.getString("Catch.invalidClassMsg"));
        } catch (ResolveException re) {
            session.getUIAdapter().showMessage(
                UIAdapter.MESSAGE_ERROR, re.errorMessage());
        }
    } // actionPerformed
} // CatchAction
